package com.install4j.api.beaninfo;

import com.install4j.runtime.installer.InstallerConstants;

/**
 * Enumeration class for all possible failure strategies of actions.
 * @see ActionBeanInfo#setDefaultFailureStrategy(FailureStrategy)
 */
public class FailureStrategy {

    /**
     * Continue after a failure.
     */
    public static final FailureStrategy CONTINUE = new FailureStrategy(InstallerConstants.FAILURE_STRATEGY_CONTINUE);

    /**
     * Quit after a failure.
     */
    public static final FailureStrategy QUIT = new FailureStrategy(InstallerConstants.FAILURE_STRATEGY_QUIT);

    /**
     * Ask the user whether to continue or to quit.
     */
    public static final FailureStrategy ASK_USER = new FailureStrategy(InstallerConstants.FAILURE_STRATEGY_ASK_USER);

    /**
     * Ask the user whether to continue, to retry or to quit.
     */
    public static final FailureStrategy ASK_USER_RETRY = new FailureStrategy(InstallerConstants.FAILURE_STRATEGY_ASK_USER_RETRY);

    private int id;

    private FailureStrategy(int id) {
        this.id = id;
    }

    /**
     * Convert to an int value.
     * @return the int value
     */
    public int getId() {
        return id;
    }
}
