package com.install4j.api.context;

import java.io.File;

/**
 * Default implementation of {@link UnattendedProgressInterface UnattendedProgressInterface}.
 * You can override its methods to customize the default behavior.
 * @author ej-technologies GmbH
 */
public class DefaultUnattendedProgressInterface implements UnattendedProgressInterface {

    private int percentCompleted;

    /**
     * Default implementation for unattended mode that does nothing.
     * @param visible <tt>true</tt> at startup and <tt>false</tt> at exit
     * @see UnattendedProgressInterface#setVisible(boolean)
     */
    public void setVisible(boolean visible) {

    }

    /**
     * Default implementation for unattended mode that does nothing.
     * @param enabled <tt>true</tt> or <tt>false</tt>
     * @see UnattendedProgressInterface#setCancelButtonEnabled(boolean)
     */
    public void setCancelButtonEnabled(boolean enabled) {

    }

    /**
     * Default implementation for unattended mode that does nothing.
     * @param visible <tt>true</tt> or <tt>false</tt>
     * @see UnattendedProgressInterface#setCancelButtonVisible(boolean)
     */
    public void setCancelButtonVisible(boolean visible) {

    }

    /**
     * Default implementation for unattended mode.
     * @return always returns <tt>false</tt>
     * @see UnattendedProgressInterface#isAskForProxy()
     */
    public boolean isAskForProxy() {
        return false;
    }

    /**
     * Default implementation for unattended mode that does nothing.
     * @param message the new message.
     * @see ProgressInterface#setStatusMessage(String)
     */
    public void setStatusMessage(String message) {

    }

    /**
     * Default implementation for unattended mode that does nothing.
     * @param message the new message.
     * @see ProgressInterface#setDetailMessage(String)
     */
    public void setDetailMessage(String message) {

    }

    /**
     * Sets the percentage of completion of the current action and saves it to a local variable.
     * @param value a value between 0 and 100.
     * @see ProgressInterface#setPercentCompleted(int)
     */
    public void setPercentCompleted(int value) {
        this.percentCompleted = value;
    }

    /**
     * Returns the last value set by {@link #setPercentCompleted(int) setPercentCompleted}.
      * @return the percentage of completion
     * @see ProgressInterface#getPercentCompleted()
     */
    public int getPercentCompleted() {
        return percentCompleted;
    }

    public void setSecondaryPercentCompleted(int value) {

    }

    /**
     * Default implementation for unattended mode that does nothing.
     * @param indeterminateProgress <tt>true</tt> or <tt>false</tt>
     * @see ProgressInterface#setIndeterminateProgress(boolean)
     */
    public void setIndeterminateProgress(boolean indeterminateProgress) {

    }

    /**
     * Default implementation for unattended mode that does nothing.
     * @param message the error message
     * @see ProgressInterface#showFailure(String)
     */
    public void showFailure(String message) {
        
    }

    /**
     * Default implementation for unattended mode.
     * @param file the file in question.
     * @return always returns {@link #OVERWRITE_NO OVERWRITE_NO}
     * @throws UserCanceledException
     * @see ProgressInterface#askOverwrite(File)
     */
    public int askOverwrite(File file) throws UserCanceledException {
        return OVERWRITE_NO;
    }

    /**
     * Default implementation for unattended mode.
     * @param file the file in question.
     * @return always returns {@link #RETRY_NO RETRY_NO}
     * @throws UserCanceledException
     * @see ProgressInterface#askRetry(File)
     */
    public int askRetry(File file) throws UserCanceledException {
        return RETRY_NO;
    }

    /**
     * Default implementation for unattended mode.
     * @param file the file in question.
     * @return always returns <tt>true</tt>
     * @throws UserCanceledException
     * @see ProgressInterface#askContinue(File)
     */
    public boolean askContinue(File file) throws UserCanceledException {
        return true;
    }
}
