package com.install4j.api.context;

import com.install4j.api.SerializableEnum;

/**
 * Enumeration class that represents the different types of launchers. The constants correspond to the different launcher types that
 * you can define in the install4j GUI.
 * @author ej-technologies GmbH
 * @see LauncherSetup#getType()
 */
public class LauncherType extends SerializableEnum {

    /**
     * Represents a console launcher.
     */
    public static final LauncherType CONSOLE = new LauncherType("console");

    /**
     * Represents a GUI launcher.
     */
    public static final LauncherType GUI = new LauncherType("gui");

    /**
     * Represents a service launcher.
     */
    public static final LauncherType SERVICE = new LauncherType("service");

    /**
     * Represents an external launcher.
     */
    public static final LauncherType EXTERNAL = new LauncherType("external");

    /**
     * Represents a custom installer application.
     */
    public static final LauncherType INSTALLER_APPLICATION = new LauncherType("installer application");

    private transient String verbose;

    private LauncherType(String verbose) {
        this.verbose = verbose;
    }

    public String toString() {
        return verbose;
    }
}
